@@ -3,13 +3,13 @@
 from __future__ import annotations
 
 import os
+import pathlib
 import re
 import unicodedata
 
 import pandas as pd
 
-
-_FILEDIR = os.path.abspath(os.path.dirname(__file__))
+from acts.core import logging
 
 
 __all__ = [
@@ -17,12 +17,20 @@ __all__ = [
     "load",
 ]
 
+logger = logging.get_logger(__name__)
+
 
 def load(name: str) -> pd.DataFrame:
     """Loads a parquet file from our datasets."""
     filename = f"{_slugify(name)}.parquet"
-    filepath = os.path.join(_FILEDIR, "parquets", filename)
-    return pd.read_parquet(filepath)
+    filedir = pathlib.Path(__file__).parent.resolve()
+    filepath = filedir.joinpath("parquets", filename)
+
+    logger.running(f"Fetching {filepath}")
+    output = pd.read_parquet(filepath)
+    logger.success(f"Fetching {filepath}")
+
+    return output
 
 
 def _slugify(value: str, *, allow_unicode: bool = False) -> str:
